@@ -45,6 +45,11 @@ def generate_script():
     file_loader = FileSystemLoader("src/huble/sklearn/templates")
     env = Environment(loader=file_loader)
     template = env.get_template("preprocess.j2")
-    parameters = {"steps_list": ["huble.sklearn.drop_duplicates(data)", "huble.sklearn.drop_duplicates(data1)"]}
+    parameters = {
+        "steps_list": [
+            "huble.sklearn.drop_duplicates(data)",
+            "huble.sklearn.drop_duplicates(data1)",
+        ]
+    }
     output = template.render(parameters)
     print(output)
