@@ -9,25 +9,14 @@ def verify_ml_dataset(dataset):
     DATA_IMBALANCE_THRESHOLD = 0.1
     TOO_MANY_ZEROES_THRESHOLD = 0.1
     FEATURE_IMPORTANCE_THRESHOLD = 0.01
-
-    checks = {
-        "null_values": "",
-        "too_many_zeroes": "",
-        "label": "",
-        "outliers": "",
-        "data_imbalance": "",
-        "data_format": "",
-        "low_importance_features": "",
-        "data_normalization": "",
-        "string_features": "",
-    }
+    dict = {"errors": [], "warnings": [], "success": []}
     Y = pd.DataFrame()
 
     # check for null values in pandas dataframe
     if dataset.isnull().values.any():
-        checks["null_values"] = "error"
+        dict["errors"].append("null_values")
     else:
-        checks["null_values"] = "ok"
+        dict["success"].append("null_values")
 
     # check for label config
     for column in dataset.columns:
@@ -35,15 +24,15 @@ def verify_ml_dataset(dataset):
             Y[column] = dataset[column]
             dataset.drop(column, axis=1, inplace=True)
     if Y.empty:
-        checks["label"] = "error"
+        dict["errors"].append("label")
     else:
-        checks["label"] = "ok"
+        dict["success"].append("label")
 
     # check for string columns in pandas dataframe
     if (dataset.dtypes == object).sum() > 0:
-        checks["string_features"] = "error"
+        dict["errors"].append("string_features")
     else:
-        checks["string_features"] = "ok"
+        dict["success"].append("string_features")
 
     # check for too many zeroes in pandas dataframe
     count = 0
@@ -51,69 +40,63 @@ def verify_ml_dataset(dataset):
         column = dataset[column_name]
         count += (column == 0).sum()
         if count > len(dataset) * TOO_MANY_ZEROES_THRESHOLD:
-            checks["too_many_zeroes"] = "warning"
+            dict["warnings"].append("too_many_zeroes")
+            break
 
     # Check for outliers
-    if checks["string_features"] == "ok":
+    if "string_features" in dict["success"]:
         z_scores = stats.zscore(dataset)
         abs_z_scores = np.abs(z_scores)
         # Select data points with a z-scores above or below 3
         filtered_entries = (abs_z_scores < 3).all(axis=1)
         if len(filtered_entries) > 0:
-            checks["outliers"] = "warning"
+            dict["warnings"].append("outliers")
         else:
-            checks["outliers"] = "ok"
+            dict["success"].append("outliers")
 
     # Check for data imbalance
-    if checks["label"] == "ok":
+    if "label" in dict["success"]:
         try:
             values = Y.value_counts()
-            if (
-                values[0] * DATA_IMBALANCE_THRESHOLD > values[1]
-                or values[1] * DATA_IMBALANCE_THRESHOLD > values[0]
-            ):
-                checks["data_imbalance"] = "warning"
+            if values[0] * DATA_IMBALANCE_THRESHOLD > values[1] or values[1] * DATA_IMBALANCE_THRESHOLD > values[0]:
+                dict["warnings"].append("data_imbalance")
             else:
-                checks["data_imbalance"] = "ok"
+                dict["success"].append("data_imbalance")
         except:
             labels = []
             for column_name in Y.columns:
                 if "label" in column_name:
                     labels.append(dataset[column_name][1])
             labels.sort()
-            if (
-                labels[0] * DATA_IMBALANCE_THRESHOLD > labels[-1]
-                or labels[-1] * DATA_IMBALANCE_THRESHOLD > labels[0]
-            ):
-                checks["data_imbalance"] = "warning"
+            if labels[0] * DATA_IMBALANCE_THRESHOLD > labels[-1] or labels[-1] * DATA_IMBALANCE_THRESHOLD > labels[0]:
+                dict["warnings"].append("data_imbalance")
             else:
-                checks["data_imbalance"] = "ok"
-
+                dict["success"].append("data_imbalance")
     # check for feature importance
-    if checks["string_features"] == "ok":
+    if "string_features" in dict["success"]:
         xgb = XGBRegressor()
         xgb.fit(dataset, Y)
         importance = xgb.feature_importances_
         for score in importance:
             if score < FEATURE_IMPORTANCE_THRESHOLD:
-                checks["low_importance_features"] = "warning"
+                dict["warnings"].append("low_importance_features")
                 break
         else:
-            checks["low_importance_features"] = "ok"
+            dict["success"].append("low_importance_features")
 
     # Data normalization
-    if checks["string_features"] == "ok":
+    if "string_features" in dict["success"]:
         for val in dataset.min():
             if val < -1:
-                checks["data_normalization"] = "warning"
+                dict["warnings"].append("data_normalization")
                 break
         else:
-            checks["data_normalization"] = "ok"
+            dict["success"].append("data_normalization")
         for val in dataset.max():
             if val > 1:
-                checks["data_normalization"] = "warning"
+                dict["warnings"].append("data_normalization")
                 break
         else:
-            checks["data_normalization"] = "ok"
+            dict["success"].append("data_normalization")
 
-    return checks
+    return dict
